PrString

Struct PrString 

pub struct PrString { /* private fields */ }

Implementations

Source

impl PrStringSuite

pub fn new() -> Result<Self, Error>

Acquire this suite from the host. Returns error if the suite is not available. Suite is released on drop.

pub fn dispose_string( &self, sdk_string: *const PrSDKString, ) -> Result<(), Error>

This will dispose of an SDKString. It is OK to pass in an empty string.

  • sdk_string - the string to dispose of
Errors
  • Error::StringNotFound - this string has not been allocated, or may have already been disposed
  • Error::InvalidParms - one of the params is invalid
pub fn allocate_from_utf8(&self, string: &str) -> Result<PrSDKString, Error>

This will allocate an SDKString from a passed in null terminated string.

  • string - UTF8 string to copy into the SDK string

Returns the allocated PrSDKString which must be disposed using dispose_string()

Errors
  • Error::StringNotFound - this string has not been allocated, or may have already been disposed
  • Error::InvalidParms - one of the params is invalid
pub fn copy_to_utf8_string( &self, sdk_string: *const PrSDKString, ) -> Result<String, Error>

This will copy an PrSDKString into a Rust’s String

Errors
  • Error::InvalidParms - one of the params is invalid